﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Pixoneer.NXDL.NXVideo;
using Microsoft.Win32;

namespace XLD_NXVideo1
{
    /// <summary>
    /// MainWindow.xaml에 대한 상호 작용 논리
    /// </summary>
    public partial class MainWindow : Window
    {
        XVideoIO m_VideoIO;          // Video 입출력에 관한 객체를 생성. XVideoIO 객체는 XVideo객체를 생성한다.
        XVideo m_Video;             // XVideo 객체는 실질적으로 비디오 스트리밍을 받아서 처리하는 객체이다.
        XVideoChannel m_channel;    // XVideoChannel은 보통 1개의 파일에는 1개의 스트리밍이 존재하지만, MPEG2TS와 같이 MultiChannel을 지원하는 것도 존재한다.
                                    // 결국 XVideoChannel이 스트리밍에 대한 파싱 및 도시를 위한 비디오 Frame 데이터 관리를 수행한다.

        public MainWindow()
        {
            InitializeComponent();
            m_VideoIO = new XVideoIO(); // VideoIO를 생성
        }

        private void openFileMenuItem_Click(object sender, RoutedEventArgs e)
        {
            // 파일 Open을 수행한다.
            OpenFileDialog openFileDialog = new OpenFileDialog();
            openFileDialog.Filter = "TS file(*.ts)|*.ts||";
            openFileDialog.RestoreDirectory = true;

            Nullable<bool> result = openFileDialog.ShowDialog();
            if (result != true) return;

            // XVideoIO 객체로부터 XVideo 객체를 생성한다.
            string strError = null;
            m_Video = m_VideoIO.OpenFile(openFileDialog.FileName, "XFFMPDRIVER", out strError);

            if (m_Video == null)
            {
                MessageBox.Show(strError);
                return;
            }

            // XVideoView 객체에 XVideo 객체와 Muti Channel인 경우를 고려하여 XVideo 객체 안의 Channel에 대한 인덱스를 설정한다.
            int nIdxChannel = 0;
            nxVideoView1.SetVideoChannel(m_Video, nIdxChannel);

            // XVideo객체로부터 특정 인덱스에 해당하는 Channel을 꺼낸다.
            m_channel = m_Video.GetChannel(nIdxChannel);

            if (m_channel == null)
            {
                MessageBox.Show("Channel is not valid");
            }

            // Channel을 활성화 시키고 Play시킨다.
            m_channel.Activate();
        }

        private void playToolsMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (m_channel == null)
            {
                MessageBox.Show(" 재생을 위한 File을 추가 하십시오.");
            }
            else
            {
                m_channel.Play();
            }
        }

        private void pauseToolsMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (m_channel == null)
            {
                MessageBox.Show("재생을 위한 File을 추가 하십시오.");
            }
            else
            {
                m_channel.Pause();
            }
        }

        private void stopToolsMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (m_channel == null)
            {
                MessageBox.Show("재생을 위한 File을 추가 하십시오.");
            }
            else
            {
                m_channel.Stop();
            }
        }

        private void resumeToolsMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (m_channel == null)
            {
                MessageBox.Show("재생을 위한 File을 추가 하십시오.");
            }
            else
            {
                m_channel.Resume();
            }
        }

        private void Window_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            // Video 종료시에 XVideoView와 XVideo와의 관계를 정리한다.
            nxVideoView1.ResetVideoChannel();
            if (m_Video != null)
                m_Video.Close();
        }
    }
}
